@@ -55,8 +55,12 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.SortedSet;
+import java.util.TimeZone;
 import java.util.TreeSet;
 import org.dmfs.rfc5545.DateTime;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import com.google.api.services.calendar.model.Event.Creator;
 import com.google.api.services.calendar.model.Event.Reminders;
 import com.google.api.services.calendar.model.EventAttendee;
@@ -81,6 +85,7 @@ import com.openexchange.chronos.Trigger.Related;
 import com.openexchange.chronos.common.CalendarUtils;
 import com.openexchange.chronos.common.DefaultRecurrenceId;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 
 /**
  * {@link GoogleEventConverter}
@@ -91,6 +96,8 @@ import com.openexchange.exception.OXException;
 public class GoogleEventConverter {
 
     private static final GoogleEventConverter INSTANCE = new GoogleEventConverter();
+    
+    public static final Logger LOG = LoggerFactory.getLogger(GoogleEventConverter.class);
 
     private Map<EventField, GoogleMapping> mappings = null;
 
@@ -130,7 +137,7 @@ public class GoogleEventConverter {
         result.put(EventField.ID, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 to.setFilename(from.getId());
             }
 
@@ -138,7 +145,7 @@ public class GoogleEventConverter {
         result.put(EventField.START_DATE, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getStart() != null) {
                     to.setStartDate(convert(from.getStart()));
                 }
@@ -148,7 +155,7 @@ public class GoogleEventConverter {
         result.put(EventField.END_DATE, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getEnd() != null) {
                     to.setEndDate(convert(from.getEnd()));
                 }
@@ -159,7 +166,7 @@ public class GoogleEventConverter {
         result.put(EventField.ALARMS, new GoogleItemMapping<EventReminder, Alarm>() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 Reminders reminders = from.getReminders();
                 if (reminders != null) {
                     List<Alarm> alarms = new ArrayList<>();
@@ -201,7 +208,7 @@ public class GoogleEventConverter {
         result.put(EventField.ATTENDEES, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
 
                 List<Attendee> attendees = new ArrayList<>();
                 if (from.getAttendees() != null) {
@@ -242,7 +249,7 @@ public class GoogleEventConverter {
         result.put(EventField.CALENDAR_USER, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getAttendees() != null) {
                     for (EventAttendee att : from.getAttendees()) {
                         if (att.getSelf() != null && att.getSelf()) {
@@ -255,7 +262,7 @@ public class GoogleEventConverter {
         result.put(EventField.ORGANIZER, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getAttendees() != null) {
                     for (EventAttendee att : from.getAttendees()) {
                         if (att.getOrganizer() != null && att.getOrganizer()) {
@@ -275,7 +282,7 @@ public class GoogleEventConverter {
         result.put(EventField.CATEGORIES, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -283,7 +290,7 @@ public class GoogleEventConverter {
         result.put(EventField.CLASSIFICATION, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -291,7 +298,7 @@ public class GoogleEventConverter {
         result.put(EventField.COLOR, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getColorId() != null) {
                     to.setColor(from.getColorId());
                 }
@@ -301,7 +308,7 @@ public class GoogleEventConverter {
         result.put(EventField.CREATED, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getCreated() != null) {
                     to.setCreated(new Date(from.getCreated().getValue()));
                 }
@@ -311,7 +318,7 @@ public class GoogleEventConverter {
         result.put(EventField.CREATED_BY, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 Creator creator = from.getCreator();
                 if (creator != null) {
                     CalendarUser result = new CalendarUser();
@@ -325,7 +332,7 @@ public class GoogleEventConverter {
         result.put(EventField.DELETE_EXCEPTION_DATES, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -333,7 +340,7 @@ public class GoogleEventConverter {
         result.put(EventField.DESCRIPTION, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getDescription() != null) {
                     to.setDescription(from.getDescription());
                 }
@@ -343,7 +350,7 @@ public class GoogleEventConverter {
         result.put(EventField.EXTENDED_PROPERTIES, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 com.google.api.services.calendar.model.Event.ExtendedProperties extendedProperties = from.getExtendedProperties();
                 if (extendedProperties != null) {
                     to.setExtendedProperties(convert(extendedProperties));
@@ -372,7 +379,7 @@ public class GoogleEventConverter {
         result.put(EventField.FILENAME, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -380,7 +387,7 @@ public class GoogleEventConverter {
         result.put(EventField.FOLDER_ID, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -388,7 +395,7 @@ public class GoogleEventConverter {
         result.put(EventField.GEO, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -396,7 +403,7 @@ public class GoogleEventConverter {
         result.put(EventField.LOCATION, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getLocation() != null) {
                     to.setLocation(from.getLocation());
                 }
@@ -406,7 +413,7 @@ public class GoogleEventConverter {
         result.put(EventField.LAST_MODIFIED, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getUpdated() != null) {
                     to.setLastModified(new Date(from.getUpdated().getValue()));
                 }
@@ -416,7 +423,7 @@ public class GoogleEventConverter {
         result.put(EventField.MODIFIED_BY, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 // There is no equivalent
             }
         });
@@ -424,13 +431,23 @@ public class GoogleEventConverter {
         result.put(EventField.RECURRENCE_ID, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getRecurringEventId() != null) {
-
-                    String dateTimeStr = from.getId().substring(from.getRecurringEventId().length() + 1);
-                    RecurrenceId recId = new DefaultRecurrenceId(dateTimeStr);
-                    to.setRecurrenceId(recId);
-                } else if (from.getId().indexOf("_") > 0) {
+                    try {
+                        if(from.getOriginalStartTime() != null) {
+                            com.google.api.client.util.DateTime rfc3339 = from.getOriginalStartTime().getDate() == null ? from.getOriginalStartTime().getDateTime() : from.getOriginalStartTime().getDate();
+                            RecurrenceId recId = new DefaultRecurrenceId(new DateTime(rfc3339.getValue()));
+                            to.setRecurrenceId(recId);
+                        } else {
+                            String dateTimeStr = from.getId().substring(from.getRecurringEventId().length() + 1);
+                            RecurrenceId recId = new DefaultRecurrenceId(dateTimeStr);
+                            to.setRecurrenceId(recId);
+                        }
+                    } catch (RuntimeException e) {
+                        LOG.warn("Error deriving recurrence identifier from Id={}, RecurringEventId={}", from.getId(), from.getRecurringEventId(), e);
+                        throw e;
+                    }
+                } else if (from.getId().indexOf('_') > 0) {
                     /*
                      * Additional check in case recurringEventId isn't set (null)
                      * This check expects that google ids of occurences to be in the following format: [masterId]_[recurrenceid]
@@ -446,7 +463,7 @@ public class GoogleEventConverter {
         result.put(EventField.RECURRENCE_RULE, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getRecurrence() != null) {
                     for (String recurrence : from.getRecurrence()) {
                         if (recurrence.startsWith("RRULE:")) {
@@ -470,7 +487,7 @@ public class GoogleEventConverter {
         result.put(EventField.SEQUENCE, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getSequence() != null) {
                     to.setSequence(from.getSequence());
                 }
@@ -480,7 +497,7 @@ public class GoogleEventConverter {
         result.put(EventField.SERIES_ID, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getRecurringEventId() != null) {
                     // Add google id to identify delete exceptions
                     to.setSeriesId(from.getRecurringEventId());
@@ -491,7 +508,7 @@ public class GoogleEventConverter {
         result.put(EventField.STATUS, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getStatus() != null) {
                     to.setStatus(new EventStatus(from.getStatus().toUpperCase()));
                 }
@@ -501,7 +518,7 @@ public class GoogleEventConverter {
         result.put(EventField.SUMMARY, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getSummary() != null) {
                     to.setSummary(from.getSummary());
                 }
@@ -511,7 +528,7 @@ public class GoogleEventConverter {
         result.put(EventField.TIMESTAMP, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getCreated() != null) {
                     to.setTimestamp(from.getCreated().getValue());
                 }
@@ -521,7 +538,7 @@ public class GoogleEventConverter {
         result.put(EventField.TRANSP, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getTransparency() != null) {
                     to.setTransp(TimeTransparency.valueOf(from.getTransparency().toUpperCase()));
                 }
@@ -531,7 +548,7 @@ public class GoogleEventConverter {
         result.put(EventField.UID, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getICalUID() != null) {
                     to.setUid(from.getICalUID());
                 }
@@ -541,7 +558,7 @@ public class GoogleEventConverter {
         result.put(EventField.URL, new GoogleMapping() {
 
             @Override
-            public void serialize(Event to, com.google.api.services.calendar.model.Event from) throws OXException {
+            public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getHtmlLink() != null) {
                     to.setUrl(from.getHtmlLink());
                 }
@@ -584,7 +601,11 @@ public class GoogleEventConverter {
 
         public DateTime convert(EventDateTime from) {
             if (from.getDateTime() == null) {
-                return new DateTime(from.getDate().getValue());
+                String timeZoneStr = from.getTimeZone();
+                TimeZone tz = Strings.isEmpty(timeZoneStr) ? TimeZone.getDefault() : TimeZone.getTimeZone(timeZoneStr);
+                java.util.Calendar cal = java.util.Calendar.getInstance(tz);
+                cal.setTimeInMillis(from.getDate().getValue());
+                return new DateTime(cal.get(java.util.Calendar.YEAR), cal.get(java.util.Calendar.MONTH), cal.get(java.util.Calendar.DAY_OF_MONTH));
             }
             return new DateTime(from.getDateTime().getValue());
         }
