@@ -55,34 +55,30 @@ import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import com.openexchange.context.ContextService;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccountDeleteListener;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.subscribe.SubscribeService;
-import com.openexchange.subscribe.google.GoogleCalendarSubscribeService;
-import com.openexchange.subscribe.google.GoogleContactSubscribeService;
+import com.openexchange.subscribe.google.GoogleContactsSubscribeService;
 import com.openexchange.subscribe.google.groupware.GoogleSubscriptionsOAuthAccountDeleteListener;
 
 /**
  * {@link OAuthServiceMetaDataRegisterer}
  *
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
+ * @since 7.10.1
  */
 public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<OAuthServiceMetaData, OAuthServiceMetaData> {
 
     private final String oauthIdentifier;
-
-    private final BundleContext context;
-
     private final ServiceLookup services;
-
-    private volatile ServiceRegistration<SubscribeService> calendarRegistration;
-
-    private volatile ServiceRegistration<SubscribeService> contactRegistration;
+    private final BundleContext context;
+    private volatile ServiceRegistration<SubscribeService> contactsRegistration;
+    private volatile ServiceRegistration<OAuthAccountDeleteListener> deleteListenerRegistration;
 
     /**
-     * Initializes a new {@link OAuthServiceMetaDataRegisterer}.
+     * Initialises a new {@link OAuthServiceMetaDataRegisterer}.
      *
      * @param services The service look-up
      * @param context The bundle context
@@ -91,55 +87,46 @@ public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<
         super();
         this.services = services;
         this.context = context;
-        oauthIdentifier = "com.openexchange.oauth.google";
+        oauthIdentifier = KnownApi.GOOGLE.getFullName();
     }
 
     @Override
     public OAuthServiceMetaData addingService(ServiceReference<OAuthServiceMetaData> ref) {
-        final Logger logger = LoggerFactory.getLogger(OAuthServiceMetaDataRegisterer.class);
-        final OAuthServiceMetaData oAuthServiceMetaData = context.getService(ref);
+        Logger logger = LoggerFactory.getLogger(OAuthServiceMetaDataRegisterer.class);
+        OAuthServiceMetaData oAuthServiceMetaData = context.getService(ref);
         if (oauthIdentifier.equals(oAuthServiceMetaData.getId())) {
-            logger.info("Registering Google subscription services.");
-            final GoogleCalendarSubscribeService calendarSubService = new GoogleCalendarSubscribeService(oAuthServiceMetaData, services);
-            final GoogleContactSubscribeService contactSubService = new GoogleContactSubscribeService(oAuthServiceMetaData, services);
-            calendarRegistration = context.registerService(SubscribeService.class, calendarSubService, null);
-            contactRegistration = context.registerService(SubscribeService.class, contactSubService, null);
-
-            ContextService contextService = services.getService(ContextService.class);
-
-            try {
-                context.registerService(OAuthAccountDeleteListener.class, new GoogleSubscriptionsOAuthAccountDeleteListener(
-                    calendarSubService,
-                    contactSubService,
-                    contextService), null);
-            } catch (final Throwable t) {
-                logger.error("", t);
-            }
+            logger.info("Registering Google Contact subscription services.");
+            GoogleContactsSubscribeService subscribeService = new GoogleContactsSubscribeService(oAuthServiceMetaData, services);
+            contactsRegistration = context.registerService(SubscribeService.class, subscribeService, null);
+            deleteListenerRegistration = context.registerService(OAuthAccountDeleteListener.class, new GoogleSubscriptionsOAuthAccountDeleteListener(subscribeService, services), null);
         }
         return oAuthServiceMetaData;
     }
 
     @Override
-    public void modifiedService(ServiceReference<OAuthServiceMetaData> ref, OAuthServiceMetaData service) {
+    public void modifiedService(ServiceReference<OAuthServiceMetaData> arg0, OAuthServiceMetaData arg1) {
         // nothing
     }
 
     @Override
     public void removedService(ServiceReference<OAuthServiceMetaData> ref, OAuthServiceMetaData service) {
-        final Logger logger = LoggerFactory.getLogger(OAuthServiceMetaDataRegisterer.class);
+        Logger logger = LoggerFactory.getLogger(OAuthServiceMetaDataRegisterer.class);
         if (service.getId().equals(oauthIdentifier)) {
-            logger.info("Unregistering Google subscription services.");
+            logger.info("Unregistering Google Contacts subscription services.");
 
-            ServiceRegistration<SubscribeService> calendarRegistration = this.calendarRegistration;
-            if (null != calendarRegistration) {
-                calendarRegistration.unregister();
-                this.calendarRegistration = null;
+            {
+                ServiceRegistration<SubscribeService> registration = this.contactsRegistration;
+                if (null != registration) {
+                    registration.unregister();
+                    this.contactsRegistration = null;
+                }
             }
-
-            ServiceRegistration<SubscribeService> contactRegistration = this.contactRegistration;
-            if (null != contactRegistration) {
-                contactRegistration.unregister();
-                this.contactRegistration = null;
+            {
+                ServiceRegistration<OAuthAccountDeleteListener> registration = this.deleteListenerRegistration;
+                if (null != registration) {
+                    registration.unregister();
+                    this.deleteListenerRegistration = null;
+                }
             }
         }
         context.ungetService(ref);
