@@ -94,7 +94,7 @@ public class ListSubscriptionAction extends AbstractSubscribeAction {
 	            if(source != null) {
 	                final SubscribeService subscribeService = source.getSubscribeService();
 	                final Subscription subscription = subscribeService.loadSubscription(context, id, services.getService(SecretService.class).getSecret(subscribeRequest.getServerSession()));
-	                if (subscription != null) {
+	                if (subscription != null && checkPermission(subscribeRequest.getServerSession(), subscription)) {
 	                    subscriptions.add(subscription);
 	                }
 	            }
