@@ -149,12 +149,6 @@ public class SubscriptionServicesActivator extends HousekeepingActivator {
         openTrackers();
     }
 
-    @Override
-    public void stopBundle() throws Exception {
-        unregisterServices();
-        closeTrackers();
-    }
-
     @Override
     protected Class<?>[] getNeededServices() {
         // Nothing to do
