@@ -60,7 +60,7 @@ import com.openexchange.oauth.OAuthAccountDeleteListener;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.subscribe.SubscribeService;
-import com.openexchange.subscribe.mslive.ContactsMSLiveSubscribeService;
+import com.openexchange.subscribe.mslive.MSLiveContactsSubscribeService;
 import com.openexchange.subscribe.mslive.groupware.MSLiveSubscriptionsOAuthAccountDeleteListener;
 
 /**
@@ -97,7 +97,7 @@ public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<
         final OAuthServiceMetaData oAuthServiceMetaData = context.getService(ref);
         if (oauthIdentifier.equals(oAuthServiceMetaData.getId())) {
             logger.info("Registering MS Live subscription services.");
-            final ContactsMSLiveSubscribeService msliveSubService = new ContactsMSLiveSubscribeService(oAuthServiceMetaData, services);
+            final MSLiveContactsSubscribeService msliveSubService = new MSLiveContactsSubscribeService(oAuthServiceMetaData, services);
             contactsRegistration = context.registerService(SubscribeService.class, msliveSubService, null);
 
             ContextService contextService = services.getService(ContextService.class);
