@@ -62,7 +62,6 @@ import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.subscribe.SubscribeService;
 import com.openexchange.subscribe.SubscriptionExecutionService;
-import com.openexchange.subscribe.crawler.CrawlerBlacklister;
 import com.openexchange.subscribe.xing.Services;
 import com.openexchange.subscribe.xing.XingSubscribeService;
 import com.openexchange.subscribe.xing.groupware.XingSubscriptionsOAuthAccountDeleteListener;
@@ -77,9 +76,6 @@ import com.openexchange.xing.access.XingOAuthAccessProvider;
 public final class XingSubscribeActivator extends HousekeepingActivator {
 
     private ServiceRegistration<SubscribeService> serviceRegistration;
-
-    private ServiceRegistration<CrawlerBlacklister> blacklisterRegistration;
-
     private ServiceRegistration<OAuthAccountDeleteListener> deleteListenerRegistration;
 
     /**
@@ -91,9 +87,7 @@ public final class XingSubscribeActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class[] {
-            OAuthService.class, ContextService.class, SessiondService.class, DatabaseService.class, XingOAuthAccessProvider.class,
-            ThreadPoolService.class };
+        return new Class[] { OAuthService.class, ContextService.class, SessiondService.class, DatabaseService.class, XingOAuthAccessProvider.class, ThreadPoolService.class };
     }
 
     @Override
@@ -106,8 +100,7 @@ public final class XingSubscribeActivator extends HousekeepingActivator {
         /*
          * Register update task
          */
-        final DefaultUpdateTaskProviderService providerService = new DefaultUpdateTaskProviderService(
-            new com.openexchange.subscribe.xing.groupware.XingCrawlerSubscriptionsRemoverTask());
+        final DefaultUpdateTaskProviderService providerService = new DefaultUpdateTaskProviderService(new com.openexchange.subscribe.xing.groupware.XingCrawlerSubscriptionsRemoverTask());
         registerService(UpdateTaskProviderService.class.getName(), providerService);
     }
 
@@ -123,23 +116,13 @@ public final class XingSubscribeActivator extends HousekeepingActivator {
      */
     public synchronized void registerSubscribeService() {
         if (null == serviceRegistration) {
-            final CrawlerBlacklister blacklister = new CrawlerBlacklister() {
-
-                @Override
-                public String getCrawlerId() {
-                    return "com.openexchange.subscribe.xing";
-                }
-            };
-            blacklisterRegistration = context.registerService(CrawlerBlacklister.class, blacklister, null);
-            final XingSubscribeService xingSubscribeService = new XingSubscribeService(this);
+            final XingSubscribeService xingSubscribeService = new XingSubscribeService(getService(OAuthServiceMetaData.class), this);
             serviceRegistration = context.registerService(SubscribeService.class, xingSubscribeService, null);
             org.slf4j.LoggerFactory.getLogger(XingSubscribeActivator.class).info("XingSubscribeService was started");
 
             // Register the delete listener
             final ContextService contextService = Services.getService(ContextService.class);
-            final XingSubscriptionsOAuthAccountDeleteListener deleteListener = new XingSubscriptionsOAuthAccountDeleteListener(
-                xingSubscribeService,
-                contextService);
+            final XingSubscriptionsOAuthAccountDeleteListener deleteListener = new XingSubscriptionsOAuthAccountDeleteListener(xingSubscribeService, contextService);
             deleteListenerRegistration = context.registerService(OAuthAccountDeleteListener.class, deleteListener, null);
         }
     }
@@ -153,11 +136,6 @@ public final class XingSubscribeActivator extends HousekeepingActivator {
             serviceRegistration.unregister();
             this.serviceRegistration = null;
         }
-        final ServiceRegistration<CrawlerBlacklister> blacklisterRegistration = this.blacklisterRegistration;
-        if (null != blacklisterRegistration) {
-            blacklisterRegistration.unregister();
-            this.blacklisterRegistration = null;
-        }
         final ServiceRegistration<OAuthAccountDeleteListener> deleteRegistration = this.deleteListenerRegistration;
         if (null != deleteRegistration) {
             deleteRegistration.unregister();
